resume

# XMLRésuméLibrary: User Guide

result | Element Reference | resumes

## Name

resume — A résumé or curriculum vitae

## Synopsis

### Content Model

    (docpath?,header?,((objective|history|academics|skillareas|skillarea|pubs|misc|referees|keywords|memberships|interests|clearances|awards))*,lastModified?,copyright?)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None
xmlns | CDATA | `http://xmlresume.sourceforge.net/resume/0.0`
xmlns:xsi | CDATA | `http://www.w3.org/2001/XMLSchema-instance`
xsi:schemaLocation | CDATA | None

## Description

The `resume` element represents a single résumé or curriculum vitae (CV). It is a summary of a person's experience that is revelant to employment.

### Parents

`resume` may be contained in these elements: `resumes`

### Attributes

`id`

  A string used to uniquely identify a résumé. The résumé may then be referred to by this identifier.

## Examples

    <resume id="a8df262">

      <header>
        <name id="harry.potter">
          <firstname>Harry</firstname>
          <surname>Potter</surname>
        </name>
        <address>
          <street>4 Privet Drive</street>
          <city>Little Whinging</city>
          <county>Surrey</county>
          <postalCode>RO51 5NF</postalCode>
          <country>UK</country>
        </address>
      </header>

      <objective>
        <para>To defeat Lord Voldemort once and for all, then to become an Auror
        for the Ministry of Magic.</para>
      </objective>

      <skillarea>
        <title>Magical Skills</title>
        <skillset>
          <title>Charms</title>
          <skill>Levitation</skill>
          <skill>Cheering</skill>
          <skill>Summoning</skill>
          <skill>Banishing</skill>
        </skillset>
        <skillset>
          <title>Spells and Curses</title>
          <skill>Unlocking Spell</skill>
          <skill>Patronus Spell</skill>
          <skill>Stunning Spell</skill>
          <skill>Disarming Spell</skill>
          <skill>Reductor Curse</skill>
          <skill>Impediment Curse</skill>
          <skill>Imperious Curse Evasion</skill>
        </skillset>
        <skillset>
          <title>Potions</title>
          <skill>Polyjuice</skill>
          <skill>Enlarging</skill>
          <skill>Antidotes</skill>
        </skillset>
        <skillset>
          <title>Flying</title>
          <skill>High-speed</skill>
          <skill>Wronski Feint</skill>
          <skill>Steep dives</skill>
          <skill>Bludger Evasion</skill>
          <skill>No-hands</skill>
          <skill>High-altitude</skill>
        </skillset>
        <skillset>
          <title>Languages</title>
          <skill>English</skill>
          <skill>Parsel Tounge</skill>
          <skill>Troll (point and grunt)</skill>
        </skillset>
      </skillarea>
      <skillarea>
        <title>Muggle Skills</title>
        <skillset>
          <title>Daily Life</title>
          <skill>Telephone</skill>
          <skill>Mailbox</skill>
          <skill>Riding in cars</skill>
          <skill>Electric lights</skill>
          <skill>Hammering</skill>
        </skillset>
        <skillset>
          <title>Camping</title>
          <skill>Setting up tents</skill>
          <skill>Lighting Matches</skill>
        </skillset>
      </skillarea>

      <history>
        <job>
          <jobtitle>Student</jobtitle>
          <employer>Hogwarts</employer>
          <period>
            <from>
              <date>
                <month>September</month>
                <year>ca. 1995</year>
              </date>
            </from>
            <to>
              <present/>
            </to>
          </period>
          <achievements>
            <achievement>
              On Gryffindor House Quidditch team four years running
            </achievement>
            <achievement>
              Quidditch Cup
            </achievement>
            <achievement>Youngest Seeker in a century</achievement>
            <achievement>
              Faced Lord Voldemort four times and lived.
            </achievement>
          </achievements>
        </job>
        <job>
          <jobtitle>De-gnomer</jobtitle>
          <employer>Mrs. Weasley</employer>
          <period>
            <from>
              <date>
                <month>August</month>
                <year>ca. 1995</year>
              </date>
            </from>
            <to>
              <date>
                <month>August</month>
                <year>ca. 1995</year>
              </date>
            </to>
          </period>
          <description>
            <para>Removed gnomes from the Weasleys' garden.</para>
          </description>
        </job>
      </history>

      <academics>
        <degrees>
          <degree>
            <level>Fourth Year</level>
            <major>Wizarding</major>
            <institution>Hogwards School of Witchcraft and Wizardry</institution>
            <subjects>
              <subject>
                <title>Transfiguration</title>
                <result>B</result>
              </subject>
              <subject>
                <title>Charms</title>
                <result>A-</result>
              </subject>
              <subject>
                <title>Defense Against the Dark Arts</title>
                <result>A</result>
              </subject>
              <subject>
                <title>Potions</title>
                <result>D</result>
              </subject>
              <subject>
                <title>Care of Magical Creature</title>
                <result>A+</result>
              </subject>
              <subject>
                <title>Divination</title>
                <result>B</result>
              </subject>
            </subjects>
          </degree>
        </degrees>
      </academics>

      <memberships>
        <title>School Clubs</title>
        <membership>
          <organization>Dueling Club</organization>
          <description><para>Trained in wizard dueling, with focus on
          disarming.</para></description>
        </membership>
        <membership>
          <title>Secretary</title>
          <organization>Society for the Protection of Elfish Workers
          (S.P.E.W.)</organization>
        </membership>
      </memberships>

      <interests>
        <interest><title>Cho Chang</title></interest>
      </interests>

      <referees>
        <referee>
          <name>
            <firstname>Minerva</firstname>
            <surname>McGonagall</surname>
          </name>
          <address>Hogwarts School of Witchcraft and Wizardry
    Via Owl Post</address>
        </referee>
        <referee>
          <name>
            <firstname>Albus</firstname>
            <surname>Dumbledore</surname>
          </name>
          <address>Hogwarts School of Witchcraft and Wizardry
    Via Owl Post</address>
        </referee>
      </referees>

    </resume>

For additional examples, look at the sample résumés in the `examples` directory of the XML Résumé Library distribution.

result | Element Reference | resumes